BottomToNavRailImpl class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addItem(
{required String label, required IconData icon, IconData? selectedIcon}) → BottomToNavRailImpl -
Typically, the size and other properties of the navigation item need to be customized.
Therefore, we use an
Iconinstead ofIconDatato reduce the need for additional wrapping in the consumer code.override -
addItems(
List< NavigationItem> items) → BottomToNavRailImpl -
override
-
override
-
appBar(
AppBar? appBar) → BottomToNavRailImpl -
override
-
body(
Widget body) → BottomToNavRailImpl -
override
-
build(
BuildContext context) → Widget -
override
-
floatingActionButton(
FloatingActionButton? fab) → BottomToNavRailImpl -
override
-
iconColor(
Color color) → BottomToNavRail -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onItemClicked(
ValueChanged< int> callback) → BottomToNavRailImpl -
override
-
selectedIndex(
int index) → BottomToNavRailImpl -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited